==> jangaroo-sdk-0.9.3.zip: joo/classes/flash/ui/ContextMenuBuiltInItems.js <==
joo.classLoader.prepare("package flash.ui",/* {*/


/**
 * The ContextMenuBuiltInItems class describes the items that are built in to a context menu. You can hide these items by using the <code>ContextMenu.hideBuiltInItems()</code> method.
 * <p><a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/flash/ui/ContextMenuBuiltInItems.html#includeExamplesSummary">View the examples</a></p>
 * @see ContextMenu#hideBuiltInItems()
 *
 */
"public final class ContextMenuBuiltInItems",1,function($$private){;return[ 
  /**
   * Lets the user move forward or backward one frame in a SWF file at run time (does not appear for a single-frame SWF file).
   */
  "public function get forwardAndBack",function forwardAndBack$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set forwardAndBack",function forwardAndBack$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set a SWF file to start over automatically when it reaches the final frame (does not appear for a single-frame SWF file).
   */
  "public function get loop",function loop$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set loop",function loop$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user start a paused SWF file (does not appear for a single-frame SWF file).
   */
  "public function get play",function play$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set play",function play$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user send the displayed frame image to a printer.
   */
  "public function get print",function print$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set print",function print$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set the resolution of the SWF file at run time.
   */
  "public function get quality",function quality$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set quality",function quality$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set a SWF file to play from the first frame when selected, at any time (does not appear for a single-frame SWF file).
   */
  "public function get rewind",function rewind$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set rewind",function rewind$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user with Shockmachine installed save a SWF file.
   */
  "public function get save",function save$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set save",function save$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user zoom in and out on a SWF file at run time.
   */
  "public function get zoom",function zoom$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set zoom",function zoom$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates a new ContextMenuBuiltInItems object so that you can set the properties for Flash Player to display or hide each menu item.
   */
  "public function ContextMenuBuiltInItems",function ContextMenuBuiltInItems$() {
    throw new Error('not implemented'); // TODO: implement!
  },
];},[],["Error"], "0.8.0", "0.9.3"
);

==> jangaroo-sdk-0.9.13.zip: joo/classes/flash/ui/ContextMenuBuiltInItems.js <==
joo.classLoader.prepare("package flash.ui",/* {*/


/**
 * The ContextMenuBuiltInItems class describes the items that are built in to a context menu. You can hide these items by using the <code>ContextMenu.hideBuiltInItems()</code> method.
 * <p><a href="http://help.adobe.com/en_US/FlashPlatform/reference/actionscript/3/flash/ui/ContextMenuBuiltInItems.html#includeExamplesSummary">View the examples</a></p>
 * @see ContextMenu#hideBuiltInItems()
 *
 */
"public final class ContextMenuBuiltInItems",1,function($$private){return[ 
  /**
   * Lets the user move forward or backward one frame in a SWF file at run time (does not appear for a single-frame SWF file).
   */
  "public function get forwardAndBack",function forwardAndBack$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set forwardAndBack",function forwardAndBack$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set a SWF file to start over automatically when it reaches the final frame (does not appear for a single-frame SWF file).
   */
  "public function get loop",function loop$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set loop",function loop$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user start a paused SWF file (does not appear for a single-frame SWF file).
   */
  "public function get play",function play$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set play",function play$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user send the displayed frame image to a printer.
   */
  "public function get print",function print$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set print",function print$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set the resolution of the SWF file at run time.
   */
  "public function get quality",function quality$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set quality",function quality$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user set a SWF file to play from the first frame when selected, at any time (does not appear for a single-frame SWF file).
   */
  "public function get rewind",function rewind$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set rewind",function rewind$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user with Shockmachine installed save a SWF file.
   */
  "public function get save",function save$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set save",function save$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Lets the user zoom in and out on a SWF file at run time.
   */
  "public function get zoom",function zoom$get()/*:Boolean*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * @private
   */
  "public function set zoom",function zoom$set(value/*:Boolean*/)/*:void*/ {
    throw new Error('not implemented'); // TODO: implement!
  },

  /**
   * Creates a new ContextMenuBuiltInItems object so that you can set the properties for Flash Player to display or hide each menu item.
   */
  "public function ContextMenuBuiltInItems",function ContextMenuBuiltInItems() {
    throw new Error('not implemented'); // TODO: implement!
  },
undefined];},[],["Error"], "0.8.0", "0.9.12"
);
